@@ -1,5 +1,8 @@
 # SPDX-FileCopyrightText: 2021 ladyada for Adafruit Industries
 # SPDX-License-Identifier: MIT
+"""
+Simple button example.
+"""
 
 import board
 import displayio
@@ -7,6 +10,11 @@ import terminalio
 import adafruit_touchscreen
 from adafruit_button import Button
 
+# use built in display (MagTag, PyPortal, PyGamer, PyBadge, CLUE, etc.)
+# see guide for setting up external displays (TFT / OLED breakouts, RGB matrices, etc.)
+# https://learn.adafruit.com/circuitpython-display-support-using-displayio/display-and-display-bus
+display = board.DISPLAY
+
 # --| Button Config |-------------------------------------------------
 BUTTON_X = 110
 BUTTON_Y = 95
@@ -26,12 +34,12 @@ ts = adafruit_touchscreen.Touchscreen(
     board.TOUCH_YD,
     board.TOUCH_YU,
     calibration=((5200, 59000), (5800, 57000)),
-    size=(320, 240),
+    size=(display.width, display.height),
 )
 
 # Make the display context
 splash = displayio.Group()
-board.DISPLAY.show(splash)
+display.show(splash)
 
 # Make the button
 button = Button(
@@ -42,7 +50,7 @@ button = Button(
     style=BUTTON_STYLE,
     fill_color=BUTTON_FILL_COLOR,
     outline_color=BUTTON_OUTLINE_COLOR,
-    label="HELLO WORLD",
+    label=BUTTON_LABEL,
     label_font=terminalio.FONT,
     label_color=BUTTON_LABEL_COLOR,
 )
@@ -56,5 +64,7 @@ while True:
     if p:
         if button.contains(p):
             button.selected = True
+        else:
+            button.selected = False  # if touch is dragged outside of button
     else:
-        button.selected = False
+        button.selected = False  # if touch is released
